@@ -629,6 +629,8 @@ class DebugBase(object):
             # No need to handle special case if a lot of lines between
             # (e.g. closure), because the additional lines won't cause a bp
             for co_lno in co_lnotab:
+                if co_lno >= 0x80:
+                    lineNo -= 0x100
                 lineNo += co_lno
                 lineNumbers.append(lineNo)
             
