@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -93,11 +93,11 @@ if sys.version_info[0] == 2:
 else:
     try:
         DebugClientOrigInput = __builtins__.__dict__['input']
-        __builtins__.__dict__['input'] = DebugClientRawInput
+        __builtins__.__dict__['input'] = DebugClientInput
     except (AttributeError, KeyError):
         import __main__
         DebugClientOrigInput = __main__.__builtins__.__dict__['input']
-        __main__.__builtins__.__dict__['input'] = DebugClientRawInput
+        __main__.__builtins__.__dict__['input'] = DebugClientInput
 
 ###############################################################################
 
@@ -518,7 +518,7 @@ class DebugClientBase(object):
                 self.mainThread.run(code, self.debugMod.__dict__, debug=False)
 
         elif method == "RequestCoverage":
-            from coverage import coverage
+            from coverage import Coverage
             sys.argv = []
             self.__setCoding(params["filename"])
             sys.argv.append(params["filename"])
@@ -535,7 +535,7 @@ class DebugClientBase(object):
             self.__interceptSignals()
             
             # generate a coverage object
-            self.cover = coverage(
+            self.cover = Coverage(
                 auto_data=True,
                 data_file="{0}.coverage".format(
                     os.path.splitext(sys.argv[0])[0]))
@@ -906,8 +906,8 @@ class DebugClientBase(object):
             
             # generate a coverage object
             if params["coverage"]:
-                from coverage import coverage
-                self.cover = coverage(
+                from coverage import Coverage
+                self.cover = Coverage(
                     auto_data=True,
                     data_file="{0}.coverage".format(
                         os.path.splitext(params["coveragefile"])[0]))
@@ -2053,16 +2053,14 @@ class DebugClientBase(object):
         self.__interceptSignals()
         
         # This will eventually enter a local event loop.
-        # Note the use of backquotes to cause a repr of self.running. The
-        # need for this is on Windows os where backslash is the path separator.
-        # They will get inadvertantly stripped away during the eval causing
-        # IOErrors if self.running is passed as a normal str.
         self.debugMod.__dict__['__file__'] = self.running
         sys.modules['__main__'] = self.debugMod
-        res = self.mainThread.run(
-            'exec(open(' + repr(self.running) + ').read())',
-            self.debugMod.__dict__)
-        self.progTerminated(res)
+        code = self.__compileFileSource(self.running)
+        if code:
+            res = self.mainThread.run(code, self.debugMod.__dict__, debug=True)
+            self.progTerminated(res)
+        else:
+            self.progTerminated(42)     # should not happen
 
     def run_call(self, scriptname, func, *args):
         """
