@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -1397,7 +1397,7 @@ class DebugUI(QObject):
             cond, temp, enabled, count, special = dlg.getData()
             
             # check for duplicates
-            idx = self.__model.getWatchPointIndex(cond, special)
+            idx = model.getWatchPointIndex(cond, special)
             duplicate = (idx.isValid() and
                          idx.internalPointer() != index.internalPointer())
             if duplicate:
