@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -519,11 +519,12 @@ class DebuggerInterfacePython(QObject):
         """
         Public slot to flush the queue.
         """
-        # Send commands that were waiting for the connection.
-        for cmd in self.queue:
-            self.__writeJsonCommandToSocket(cmd)
-        
-        self.queue = []
+        if self.qsock is not None:
+            # Send commands that were waiting for the connection.
+            for cmd in self.queue:
+                self.__writeJsonCommandToSocket(cmd)
+            
+            self.queue = []
     
     def shutdown(self):
         """
