@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Watch expression model.
 """
 
-from __future__ import unicode_literals
 
 from PyQt5.QtCore import pyqtSignal, Qt, QAbstractItemModel, QModelIndex
 
@@ -133,9 +132,13 @@ class WatchPointModel(QAbstractItemModel):
         @param parent index of the parent item (QModelIndex)
         @return requested index (QModelIndex)
         """
-        if (parent and parent.isValid()) or \
-           row < 0 or row >= len(self.watchpoints) or \
-           column < 0 or column >= len(self.header):
+        if (
+            (parent and parent.isValid()) or
+            row < 0 or
+            row >= len(self.watchpoints) or
+            column < 0 or
+            column >= len(self.header)
+        ):
             return QModelIndex()
         
         return self.createIndex(row, column, self.watchpoints[row])
