@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2019 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -561,7 +561,12 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         """
         Private slot initiating a search via a press of the Return key.
         """
-        self.__search()
+        if (
+            (bool(self.searchEditName.text()) or
+             bool(self.searchEditSummary.text())) and
+            self.__isPipAvailable()
+        ):
+            self.__search()
     
     @pyqtSlot(str)
     def on_searchEditSummary_textChanged(self, txt):
@@ -578,7 +583,12 @@ class PipPackagesWidget(QWidget, Ui_PipPackagesWidget):
         """
         Private slot initiating a search via a press of the Return key.
         """
-        self.__search()
+        if (
+            (bool(self.searchEditName.text()) or
+             bool(self.searchEditSummary.text())) and
+            self.__isPipAvailable()
+        ):
+            self.__search()
     
     @pyqtSlot()
     def on_searchButton_clicked(self):
