@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -117,6 +117,51 @@ _messages = {
     'F33': QCoreApplication.translate(
         'pyFlakes',
         "use ==/!= to compare str, bytes, and int literals"),
+    'F34': QCoreApplication.translate(
+        'pyFlakes',
+        "f-string is missing placeholders"),
+    'F35': QCoreApplication.translate(
+        'pyFlakes',
+        "'...'.format(...) has unused arguments at position(s): {0}"),
+    'F36': QCoreApplication.translate(
+        'pyFlakes',
+        "'...'.format(...) has unused named argument(s): {0}"),
+    'F37': QCoreApplication.translate(
+        'pyFlakes',
+        "'...'.format(...) is missing argument(s) for placeholder(s): {0}"),
+    'F38': QCoreApplication.translate(
+        'pyFlakes',
+        "'...'.format(...) mixes automatic and manual numbering"),
+    'F39': QCoreApplication.translate(
+        'pyFlakes',
+        "'...'.format(...) has invalid format string: {0}"),
+    'F40': QCoreApplication.translate(
+        'pyFlakes',
+        "'...' % ... has invalid format string: {0}"),
+    'F41': QCoreApplication.translate(
+        'pyFlakes',
+        "'...' % ... has mixed positional and named placeholders"),
+    'F42': QCoreApplication.translate(
+        'pyFlakes',
+        "'...' % ... has unsupported format character {0!r}"),
+    'F43': QCoreApplication.translate(
+        'pyFlakes',
+        "'...' % ... has {0!d} placeholder(s) but {1!d} substitution(s)"),
+    'F44': QCoreApplication.translate(
+        'pyFlakes',
+        "'...' % ... has unused named argument(s): {0}"),
+    'F45': QCoreApplication.translate(
+        'pyFlakes',
+        "'...' % ... is missing argument(s) for placeholder(s): {0}"),
+    'F46': QCoreApplication.translate(
+        'pyFlakes',
+        "'...' % ... expected mapping but got sequence"),
+    'F47': QCoreApplication.translate(
+        'pyFlakes',
+        "'...' % ... expected sequence but got mapping"),
+    'F48': QCoreApplication.translate(
+        'pyFlakes',
+        "'...' % ... `*` specifier requires sequence"),
 }
 
 
