@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -359,7 +359,7 @@ class GitStatusDialog(QWidget, Ui_GitStatusDialog):
             itm.setIcon(self.__statusWorkColumn,
                         UI.PixmapCache.getIcon(
                             os.path.join("VcsPlugins", "vcsGit", "icons",
-                                         "conflict.png")))
+                                         "conflict.svg")))
         itm.setData(0, self.ConflictRole, status in self.ConflictStates)
     
     def start(self, fn):
