@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -1508,7 +1508,7 @@ class GitProjectHelper(VcsProjectHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsGit", "icons", "git.png")),
+                os.path.join("VcsPlugins", "vcsGit", "icons", "git.svg")),
             self.vcs.vcsName(), self._vcsInfoDisplay)
         font = act.font()
         font.setBold(True)
