@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -34,8 +34,11 @@ class HgServeDialog(E5MainWindow):
         Constructor
         
         @param vcs reference to the vcs object
-        @param path path of the repository to serve (string)
-        @param parent reference to the parent widget (QWidget)
+        @type Hg
+        @param path path of the repository to serve
+        @type str
+        @param parent reference to the parent widget
+        @type QWidget
         """
         super(HgServeDialog, self).__init__(parent)
         
@@ -46,16 +49,21 @@ class HgServeDialog(E5MainWindow):
         
         self.setWindowTitle(self.tr("Mercurial Server"))
         
+        if e5App().usesDarkPalette():
+            iconSuffix = "dark"
+        else:
+            iconSuffix = "light"
+        
         self.__startAct = QAction(
             UI.PixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons",
-                             "startServer.png")),
+                             "startServer-{0}.svg".format(iconSuffix))),
             self.tr("Start Server"), self)
         self.__startAct.triggered.connect(self.__startServer)
         self.__stopAct = QAction(
             UI.PixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons",
-                             "stopServer.png")),
+                             "stopServer-{0}.svg".format(iconSuffix))),
             self.tr("Stop Server"), self)
         self.__stopAct.triggered.connect(self.__stopServer)
         self.__browserAct = QAction(
@@ -176,7 +184,8 @@ class HgServeDialog(E5MainWindow):
         """
         Protected slot implementing a close event handler.
         
-        @param e close event (QCloseEvent)
+        @param e close event
+        @type QCloseEvent
         """
         self.__stopServer()
     
@@ -184,8 +193,10 @@ class HgServeDialog(E5MainWindow):
         """
         Private slot connected to the finished signal.
         
-        @param exitCode exit code of the process (integer)
-        @param exitStatus exit status of the process (QProcess.ExitStatus)
+        @param exitCode exit code of the process
+        @type int
+        @param exitStatus exit status of the process
+        @type QProcess.ExitStatus
         """
         self.__stopServer()
     
@@ -215,8 +226,10 @@ class HgServeDialog(E5MainWindow):
         """
         Private method to append text to the end.
         
-        @param txt text to insert (string)
-        @param error flag indicating to insert error text (boolean)
+        @param txt text to insert
+        @type str
+        @param error flag indicating to insert error text
+        @type bool
         """
         tc = self.__log.textCursor()
         tc.movePosition(QTextCursor.End)
