@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -279,7 +279,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         act = menu.addAction(
             UI.PixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons",
-                             "mercurial.png")),
+                             "mercurial.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -391,7 +391,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         act = menu.addAction(
             UI.PixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons",
-                             "mercurial.png")),
+                             "mercurial.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -475,7 +475,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         act = menu.addAction(
             UI.PixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons",
-                             "mercurial.png")),
+                             "mercurial.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -514,7 +514,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         act = menu.addAction(
             UI.PixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons",
-                             "mercurial.png")),
+                             "mercurial.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -609,7 +609,7 @@ class HgProjectBrowserHelper(VcsProjectBrowserHelper):
         act = menu.addAction(
             UI.PixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons",
-                             "mercurial.png")),
+                             "mercurial.svg")),
             self.vcs.vcsName(), self._VCSInfoDisplay)
         font = act.font()
         font.setBold(True)
