@@ -1,13 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the VCS project helper for Mercurial.
 """
 
-from __future__ import unicode_literals
 
 import os
 
@@ -49,6 +48,7 @@ class HgProjectHelper(VcsProjectHelper):
         from .LargefilesExtension.ProjectHelper import LargefilesProjectHelper
         from .StripExtension.ProjectHelper import StripProjectHelper
         from .HisteditExtension.ProjectHelper import HisteditProjectHelper
+        from .CloseheadExtension.ProjectHelper import CloseheadProjectHelper
         self.__extensions = {
             "mq": QueuesProjectHelper(),
             "fetch": FetchProjectHelper(),
@@ -59,6 +59,7 @@ class HgProjectHelper(VcsProjectHelper):
             "largefiles": LargefilesProjectHelper(),
             "strip": StripProjectHelper(),
             "histedit": HisteditProjectHelper(),
+            "closehead": CloseheadProjectHelper(),
         }
         
         self.__extensionMenuTitles = {}
@@ -417,20 +418,34 @@ class HgProjectHelper(VcsProjectHelper):
         self.vcsMergeAct.triggered.connect(self._vcsMerge)
         self.actions.append(self.vcsMergeAct)
         
-        self.hgCancelMergeAct = E5Action(
-            self.tr('Cancel uncommitted merge'),
-            self.tr('Cancel uncommitted merge'),
-            0, 0, self, 'mercurial_cancel_merge')
-        self.hgCancelMergeAct.setStatusTip(self.tr(
-            'Cancel an uncommitted merge and lose all changes'
+        self.hgCommitMergeAct = E5Action(
+            self.tr('Commit Merge'),
+            self.tr('Commit Merge'),
+            0, 0, self, 'mercurial_commit_merge')
+        self.hgCommitMergeAct.setStatusTip(self.tr(
+            'Commit all the merged changes.'
         ))
-        self.hgCancelMergeAct.setWhatsThis(self.tr(
-            """<b>Cancel uncommitted merge</b>"""
-            """<p>This cancels an uncommitted merge causing all changes"""
+        self.hgCommitMergeAct.setWhatsThis(self.tr(
+            """<b>Commit a merge</b>"""
+            """<p>This commits a merge working directory</p>"""
+        ))
+        self.hgCommitMergeAct.triggered.connect(self.__hgCommitMerge)
+        self.actions.append(self.hgCommitMergeAct)
+        
+        self.hgAbortMergeAct = E5Action(
+            self.tr('Abort Merge'),
+            self.tr('Abort Merge'),
+            0, 0, self, 'mercurial_cancel_merge')
+        self.hgAbortMergeAct.setStatusTip(self.tr(
+            'Abort an uncommitted merge and lose all changes'
+        ))
+        self.hgAbortMergeAct.setWhatsThis(self.tr(
+            """<b>Abort uncommitted merge</b>"""
+            """<p>This aborts an uncommitted merge causing all changes"""
             """ to be lost.</p>"""
         ))
-        self.hgCancelMergeAct.triggered.connect(self.__hgCancelMerge)
-        self.actions.append(self.hgCancelMergeAct)
+        self.hgAbortMergeAct.triggered.connect(self.__hgAbortMerge)
+        self.actions.append(self.hgAbortMergeAct)
         
         self.hgReMergeAct = E5Action(
             self.tr('Re-Merge'),
@@ -554,6 +569,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgPushBranchAct = E5Action(
             self.tr('Push new branch'),
+            UI.PixmapCache.getIcon("vcsCommit.png"),
             self.tr('Push new branch'),
             0, 0, self, 'mercurial_push_branch')
         self.hgPushBranchAct.setStatusTip(self.tr(
@@ -570,6 +586,7 @@ class HgProjectHelper(VcsProjectHelper):
         
         self.hgCloseBranchAct = E5Action(
             self.tr('Close branch'),
+            UI.PixmapCache.getIcon("closehead"),
             self.tr('Close branch'),
             0, 0, self, 'mercurial_close_branch')
         self.hgCloseBranchAct.setStatusTip(self.tr(
@@ -1294,6 +1311,8 @@ class HgProjectHelper(VcsProjectHelper):
         self.hgBookmarkOutgoingAct.setEnabled(self.vcs.canPush())
         if self.vcs.version >= (3, 8):
             self.hgBookmarkPushCurrentAct.setEnabled(self.vcs.canPull())
+        self.hgCommitMergeAct.setEnabled(
+            self.vcs.canCommitMerge(self.project.ppath))
     
     def initMenu(self, menu):
         """
@@ -1430,12 +1449,13 @@ class HgProjectHelper(VcsProjectHelper):
         mergeMenu.addAction(self.vcsResolveAct)
         mergeMenu.addAction(self.hgUnresolveAct)
         mergeMenu.addAction(self.hgReMergeAct)
-        mergeMenu.addAction(self.hgCancelMergeAct)
+        mergeMenu.addAction(self.hgCommitMergeAct)
+        mergeMenu.addAction(self.hgAbortMergeAct)
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
                 os.path.join("VcsPlugins", "vcsMercurial", "icons",
-                             "mercurial.png")),
+                             "mercurial.svg")),
             self.vcs.vcsName(), self._vcsInfoDisplay)
         font = act.font()
         font.setBold(True)
@@ -1517,9 +1537,11 @@ class HgProjectHelper(VcsProjectHelper):
         
         title = self.__toolbar.windowTitle()
         toolbarManager.addToolBar(self.__toolbar, title)
+        toolbarManager.addAction(self.hgIncomingAct, title)
         toolbarManager.addAction(self.hgPullAct, title)
         toolbarManager.addAction(self.vcsUpdateAct, title)
         toolbarManager.addAction(self.vcsCommitAct, title)
+        toolbarManager.addAction(self.hgOutgoingAct, title)
         toolbarManager.addAction(self.hgPushAct, title)
         toolbarManager.addAction(self.hgPushForcedAct, title)
         toolbarManager.addAction(self.hgExtDiffAct, title)
@@ -1527,6 +1549,7 @@ class HgProjectHelper(VcsProjectHelper):
         toolbarManager.addAction(self.vcsRevertAct, title)
         toolbarManager.addAction(self.vcsMergeAct, title)
         toolbarManager.addAction(self.hgReMergeAct, title)
+        toolbarManager.addAction(self.hgCommitMergeAct, title)
         toolbarManager.addAction(self.vcsTagAct, title)
         toolbarManager.addAction(self.hgBranchAct, title)
         toolbarManager.addAction(self.vcsSwitchAct, title)
@@ -1539,13 +1562,18 @@ class HgProjectHelper(VcsProjectHelper):
         toolbarManager.addAction(self.hgBookmarkDeleteAct, title)
         toolbarManager.addAction(self.hgBookmarkRenameAct, title)
         toolbarManager.addAction(self.hgBookmarkMoveAct, title)
+        toolbarManager.addAction(self.hgBookmarkIncomingAct, title)
         toolbarManager.addAction(self.hgBookmarkPullAct, title)
+        toolbarManager.addAction(self.hgBookmarkPullCurrentAct, title)
+        toolbarManager.addAction(self.hgBookmarkOutgoingAct, title)
         toolbarManager.addAction(self.hgBookmarkPushAct, title)
+        toolbarManager.addAction(self.hgBookmarkPushCurrentAct, title)
         toolbarManager.addAction(self.hgImportAct, title)
         toolbarManager.addAction(self.hgExportAct, title)
         toolbarManager.addAction(self.hgBundleAct, title)
         toolbarManager.addAction(self.hgPreviewBundleAct, title)
         toolbarManager.addAction(self.hgUnbundleAct, title)
+        toolbarManager.addAction(self.hgDeleteBackupsAct, title)
         
         self.__toolbar.setEnabled(False)
         self.__toolbar.setVisible(False)
@@ -1609,10 +1637,14 @@ class HgProjectHelper(VcsProjectHelper):
         for extensionName in self.extensionMenus:
             self.extensionMenus[extensionName].setEnabled(
                 self.vcs.isExtensionActive(extensionName))
-            if not self.extensionMenus[extensionName].isEnabled() and \
-                    self.extensionMenus[extensionName].menu()\
-                        .isTearOffMenuVisible():
+            if (
+                not self.extensionMenus[extensionName].isEnabled() and
+                self.extensionMenus[extensionName].menu()
+                .isTearOffMenuVisible()
+            ):
                 self.extensionMenus[extensionName].menu().hideTearOffMenu()
+        if self.vcs.version < (4, 8, 0):
+            self.extensionMenus["closehead"].setEnabled(False)
     
     def __hgExtendedDiff(self):
         """
@@ -1692,12 +1724,18 @@ class HgProjectHelper(VcsProjectHelper):
         unresolved.
         """
         self.vcs.hgResolved(self.project.ppath, unresolve=True)
+
+    def __hgCommitMerge(self):
+        """
+        Private slot used to commit a merge.
+        """
+        self.vcs.vcsCommit(self.project.ppath, self.tr('Merge'), merge=True)
     
-    def __hgCancelMerge(self):
+    def __hgAbortMerge(self):
         """
-        Private slot used to cancel an uncommitted merge.
+        Private slot used to abort an uncommitted merge.
         """
-        self.vcs.hgCancelMerge(self.project.ppath)
+        self.vcs.hgAbortMerge(self.project.ppath)
     
     def __hgShowConflicts(self):
         """
