@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -493,7 +493,7 @@ class PySvnProjectHelper(VcsProjectHelper):
         
         act = menu.addAction(
             UI.PixmapCache.getIcon(
-                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.png")),
+                os.path.join("VcsPlugins", "vcsPySvn", "icons", "pysvn.svg")),
             self.vcs.vcsName(), self._vcsInfoDisplay)
         font = act.font()
         font.setBold(True)
