@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -386,7 +386,7 @@ class ConfigurationWidget(QWidget):
                 # 'save' to save the settings.
                 "interfacePage":
                 [self.tr("Interface"), "preferences-interface.png",
-                 "HelpInterfacePage", None, None],
+                 "WebBrowserInterfacePage", None, None],
                 "networkPage":
                 [self.tr("Network"), "preferences-network.png",
                  "NetworkPage", None, None],
