@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -30,6 +30,8 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
     """
     Class implementing the Programs page.
     """
+    ToolAvailableRole = Qt.UserRole + 1
+    
     def __init__(self, parent=None):
         """
         Constructor
@@ -51,6 +53,12 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         self.searchButton.setToolTip(
             self.tr("Press to search for programs"))
         
+        self.showComboBox.addItems([
+            self.tr("All Supported Tools"),
+            self.tr("Available Tools Only"),
+            self.tr("Unavailable Tools Only"),
+        ])
+        
     def show(self):
         """
         Public slot to show the dialog.
@@ -195,12 +203,12 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         self.__createProgramEntry(
             self.tr("Forms Compiler (Python, PySide2)"),
             Utilities.generatePySideToolPath("pyside2-uic", "2"),
-            '--version', 'PySide2 User', -1, versionCleanup=(0, -1))
+            '--version', '', -1, versionRe='uic')
         # 3.2c Resource Compiler PySide2
         self.__createProgramEntry(
             self.tr("Resource Compiler (Python, PySide2)"),
             Utilities.generatePySideToolPath("pyside2-rcc", "2"),
-            '-version', 'Resource Compiler', -1)
+            '-version', '', -1, versionRe='rcc')
         
         # 4. do the Ruby programs
         # 4a. Forms Compiler for Qt4
@@ -290,6 +298,23 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         self.__createEntry(
             self.tr("Source Highlighter - Pygments"), text, version)
         
+        # 10. do the MicroPython related entries
+        exe = Preferences.getMicroPython("MpyCrossCompiler")
+        if not exe:
+            exe = "mpy-cross"
+        self.__createProgramEntry(
+            self.tr("MicroPython - MPY Cross Compiler"), exe, '--version',
+            'MicroPython', 1)
+        self.__createProgramEntry(
+            self.tr("MicroPython - ESP Tool"), sys.executable, 'version',
+            'esptool', -1, exeModule=['-m', 'esptool'])
+        exe = Preferences.getMicroPython("DfuUtilPath")
+        if not exe:
+            exe = "dfu-util"
+        self.__createProgramEntry(
+            self.tr("MicroPython - PyBoard Flasher"), exe, '--version',
+            'dfu-util', -1)
+        
         # 10. do the plugin related programs
         pm = e5App().getObject("PluginManager")
         for info in pm.getPluginExeDisplayData():
@@ -317,6 +342,8 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                 )
         
         self.programsList.sortByColumn(0, Qt.AscendingOrder)
+        self.on_showComboBox_currentIndexChanged(
+            self.showComboBox.currentIndex())
         QApplication.restoreOverrideCursor()
         
         self.__hasSearched = True
@@ -366,6 +393,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
             else:
                 exe = Utilities.getExecutablePath(exe)
             if exe:
+                available = True
                 if (
                     versionCommand and
                     (versionStartsWith != "" or
@@ -392,6 +420,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                              proc.exitCode() != 0)
                         ):
                             version = self.tr("(module not found)")
+                            available = False
                         else:
                             if versionRe is None:
                                 versionRe = "^{0}".format(
@@ -409,23 +438,28 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                                         break
                                     except IndexError:
                                         version = self.tr("(unknown)")
+                                        available = False
                             else:
                                 version = self.tr("(unknown)")
+                                available = False
                     else:
                         version = self.tr("(not executable)")
+                        available = False
                 if exeModule:
-                    QTreeWidgetItem(itm, [
+                    citm = QTreeWidgetItem(itm, [
                         "{0} {1}".format(exe, " ".join(exeModule)),
                         version])
                 else:
-                    QTreeWidgetItem(itm, [exe, version])
+                    citm = QTreeWidgetItem(itm, [exe, version])
+                citm.setData(0, self.ToolAvailableRole, available)
                 itm.setExpanded(True)
             else:
                 if itm.childCount() == 0:
                     itm.setText(1, self.tr("(not found)"))
                 else:
-                    QTreeWidgetItem(itm, [rememberedExe,
-                                          self.tr("(not found)")])
+                    citm = QTreeWidgetItem(
+                        itm, [rememberedExe, self.tr("(not found)")])
+                    citm.setData(0, self.ToolAvailableRole, False)
                     itm.setExpanded(True)
         QApplication.processEvents()
         self.programsList.header().resizeSections(QHeaderView.ResizeToContents)
@@ -446,10 +480,50 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         itm.setFont(0, font)
         
         if len(entryVersion):
-            QTreeWidgetItem(itm, [entryText, entryVersion])
+            citm = QTreeWidgetItem(itm, [entryText, entryVersion])
             itm.setExpanded(True)
+            citm.setData(0, self.ToolAvailableRole,
+                         not entryVersion.startswith("("))
+            # assume version starting with '(' is an unavailability
         else:
             itm.setText(1, self.tr("(not found)"))
         QApplication.processEvents()
         self.programsList.header().resizeSections(QHeaderView.ResizeToContents)
         self.programsList.header().setStretchLastSection(True)
+    
+    @pyqtSlot(int)
+    def on_showComboBox_currentIndexChanged(self, index):
+        """
+        Private slot to apply the selected show criteria.
+        
+        @param index index of the show criterium
+        @type int
+        """
+        if index == 0:
+            # All Supported Tools
+            for topIndex in range(self.programsList.topLevelItemCount()):
+                topItem = self.programsList.topLevelItem(topIndex)
+                for childIndex in range(topItem.childCount()):
+                    topItem.child(childIndex).setHidden(False)
+                topItem.setHidden(False)
+        else:
+            # 1 = Available Tools Only
+            # 2 = Unavailable Tools Only
+            for topIndex in range(self.programsList.topLevelItemCount()):
+                topItem = self.programsList.topLevelItem(topIndex)
+                if topItem.childCount() == 0:
+                    topItem.setHidden(index == 1)
+                else:
+                    availabilityList = []
+                    for childIndex in range(topItem.childCount()):
+                        childItem = topItem.child(childIndex)
+                        available = childItem.data(0, self.ToolAvailableRole)
+                        if index == 1:
+                            childItem.setHidden(not available)
+                        else:
+                            childItem.setHidden(available)
+                        availabilityList.append(available)
+                    if index == 1:
+                        topItem.setHidden(not any(availabilityList))
+                    else:
+                        topItem.setHidden(all(availabilityList))
