@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,7 +16,7 @@ from PyQt5.QtCore import (
     pyqtSlot, Qt, QMetaObject, QRegExp, QSortFilterProxyModel, QProcess,
     QProcessEnvironment
 )
-from PyQt5.QtGui import QStandardItemModel, QBrush, QStandardItem
+from PyQt5.QtGui import QStandardItemModel, QStandardItem, QBrush, QColor
 from PyQt5.QtWidgets import QDialog, QDialogButtonBox
 
 
@@ -338,7 +338,10 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
                             itm2.setFlags(
                                 Qt.ItemFlags(Qt.ItemIsEnabled))
                             itm2.setCheckState(Qt.Checked)
-                            itm2.setForeground(QBrush(Qt.blue))
+                            if e5App().usesDarkPalette():
+                                itm2.setForeground(QBrush(QColor("#75bfff")))
+                            else:
+                                itm2.setForeground(QBrush(Qt.blue))
                             continue
             
                     itm2.setData(methodDict["pyqt_signature"],
