@@ -137,7 +137,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 self.tr('Generate Dialog Code...'),
                 self.__generateDialogCode)
             self.menu.addSeparator()
-            self.menu.addAction(
+            self.__pyuicConfigAct = self.menu.addAction(
                 self.tr('Configure uic Compiler'),
                 self.__configureUicCompiler)
             self.menu.addSeparator()
@@ -220,7 +220,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             self.backMenu.addAction(
                 self.tr('Compile all forms'), self.__compileAllForms)
             self.backMenu.addSeparator()
-            self.backMenu.addAction(
+            self.__pyuicBackConfigAct = self.backMenu.addAction(
                 self.tr('Configure uic Compiler'),
                 self.__configureUicCompiler)
             self.backMenu.addSeparator()
@@ -251,7 +251,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             self.multiMenu.addAction(
                 self.tr('Compile forms'), self.__compileSelectedForms)
             self.multiMenu.addSeparator()
-            self.multiMenu.addAction(
+            self.__pyuicMultiConfigAct = self.multiMenu.addAction(
                 self.tr('Configure uic Compiler'),
                 self.__configureUicCompiler)
             self.multiMenu.addSeparator()
@@ -298,7 +298,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             self.dirMenu.addAction(
                 self.tr('Compile all forms'), self.__compileAllForms)
             self.dirMenu.addSeparator()
-            self.dirMenu.addAction(
+            self.__pyuicDirConfigAct = self.dirMenu.addAction(
                 self.tr('Configure uic Compiler'),
                 self.__configureUicCompiler)
             self.dirMenu.addSeparator()
@@ -349,7 +349,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             self.dirMultiMenu.addAction(
                 self.tr('Compile all forms'), self.__compileAllForms)
             self.dirMultiMenu.addSeparator()
-            self.dirMultiMenu.addAction(
+            self.__pyuicDirMultiConfigAct = self.dirMultiMenu.addAction(
                 self.tr('Configure uic Compiler'),
                 self.__configureUicCompiler)
             self.dirMultiMenu.addSeparator()
@@ -390,6 +390,13 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         if not self.project.isOpen():
             return
         
+        enable = self.project.getProjectType() in ("Qt4", "PyQt5", "E6Plugin")
+        self.__pyuicConfigAct.setEnabled(enable)
+        self.__pyuicMultiConfigAct.setEnabled(enable)
+        self.__pyuicDirConfigAct.setEnabled(enable)
+        self.__pyuicDirMultiConfigAct.setEnabled(enable)
+        self.__pyuicBackConfigAct.setEnabled(enable)
+        
         try:
             categories = self.getSelectedItemsCountCategorized(
                 [ProjectBrowserFileItem, ProjectBrowserSimpleDirectoryItem])
@@ -840,17 +847,18 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
         ]:
             dirname, filename = os.path.split(ofn)
             self.compiledFile = os.path.join(dirname, "Ui_" + filename + ".py")
-            args.append("-x")
-            indentWidth = Preferences.getQt("PyuicIndent")
-            if indentWidth != self.PyuicIndentDefault:
-                args.append("--indent={0}".format(indentWidth))
             
             if self.project.getProjectType() in ["PySide", "PySide2"]:
                 # PySide and PySide2
-                if Preferences.getQt("PyuicFromImports"):
+                if Preferences.getQt("PySide2FromImports"):
                     args.append("--from-imports")
             else:
                 # PyQt4 and PyQt5
+                if Preferences.getQt("PyuicExecute"):
+                    args.append("-x")
+                indentWidth = Preferences.getQt("PyuicIndent")
+                if indentWidth != self.PyuicIndentDefault:
+                    args.append("--indent={0}".format(indentWidth))
                 if (
                     'uic5' in uicompiler and
                     self.project.pdata["UICPARAMS"]["Package"]
@@ -1098,12 +1106,6 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                 if root != params["PackagesRoot"]:
                     params["PackagesRoot"] = root
                     self.project.setDirty(True)
-        elif self.project.getProjectType() in ["PySide", "PySide2"]:
-            E5MessageBox.information(
-                self,
-                self.tr("Configure uic Compiler"),
-                self.tr("""No project specific uic compiler flags are"""
-                        """ supported for PySide or PySide2."""))
     
     ###########################################################################
     ## Support for hooks below
