@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -74,11 +74,22 @@ class PixmapCache(object):
     def addSearchPath(self, path):
         """
         Public method to add a path to the search path.
-
-        @param path path to add (string)
+        
+        @param path path to add
+        @type str
         """
         if path not in self.searchPath:
             self.searchPath.append(path)
+    
+    def removeSearchPath(self, path):
+        """
+        Public method to remove a path from the search path.
+        
+        @param path path to remove
+        @type str
+        """
+        if path in self.searchPath:
+            self.searchPath.remove(path)
 
 pixCache = PixmapCache()
 
@@ -176,7 +187,21 @@ def addSearchPath(path, cache=pixCache):
     """
     Module function to add a path to the search path.
 
-    @param path path to add (string)
-    @param cache reference to the pixmap cache object (PixmapCache)
+    @param path path to add
+    @type str
+    @param cache reference to the pixmap cache object
+    @type PixmapCache
     """
     cache.addSearchPath(path)
+
+
+def removeSearchPath(path, cache=pixCache):
+    """
+    Public method to remove a path from the search path.
+    
+    @param path path to remove
+    @type str
+    @param cache reference to the pixmap cache object
+    @type PixmapCache
+    """
+    cache.removeSearchPath(path)
