@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -14,7 +14,6 @@ This is module is based on pyclbr found in the Python 2.2.2 distribution.
 
 
 import sys
-import imp
 import re
 
 import Utilities
@@ -370,14 +369,6 @@ def readmodule_ex(module, path=None, inpackage=False, isPyFile=False):
         fullpath = path[:] + sys.path[:]
         f, file, (suff, mode, type) = ClassBrowsers.find_module(
             module, fullpath, isPyFile)
-    if module.endswith(".py") and type == imp.PKG_DIRECTORY:
-        return dictionary
-    if type == imp.PKG_DIRECTORY:
-        dictionary['__path__'] = [file]
-        _modules[module] = dictionary
-        path = [file] + path
-        f, file, (suff, mode, type) = ClassBrowsers.find_module(
-            '__init__', [file])
     if f:
         f.close()
     if type not in SUPPORTED_TYPES:
