@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -1846,6 +1846,11 @@ def generatePySideToolPath(toolname, variant="2"):
         if toolname in ["pyside-uic", "pyside2-uic"]:
             return os.path.join(prefix, "Scripts", toolname + '.exe')
         else:
+            path = os.path.join(prefix, "Scripts", toolname + '.exe')
+            if os.path.exists(path):
+                return path
+            
+            # report it the old style
             return os.path.join(
                 prefix, "Lib", "site-packages",
                 "PySide{0}".format("" if variant == "1" else variant),
@@ -1853,13 +1858,24 @@ def generatePySideToolPath(toolname, variant="2"):
     else:
         if variant == "1":
             return toolname
-        
-        elif toolname == "pyside2-uic":
-            return toolname
         else:
-            import distutils.sysconfig
-            return os.path.join(distutils.sysconfig.get_python_lib(True),
-                                "PySide2", toolname)
+            # step 1: check, if the user has configured a tools path
+            path = Preferences.getQt("PySide2ToolsDir")
+            if path:
+                return os.path.join(path, toolname)
+            
+            # step 2: determine from used Python interpreter
+            dirName = os.path.dirname(sys.executable)
+            if os.path.exists(os.path.join(dirName, toolname)):
+                return os.path.join(dirName, toolname)
+            
+            # step 3: if it is not 'pyside2-uic' look in the package directory
+            if toolname == "pyside2-uic":
+                return toolname
+            else:
+                import distutils.sysconfig
+                return os.path.join(distutils.sysconfig.get_python_lib(True),
+                                    "PySide2", toolname)
 
 
 def checkPyside(variant="2"):
@@ -1927,7 +1943,18 @@ def generateVersionInfo(linesep='\n'):
         linesep, sys.version.split()[0], sizeStr, linesep)
     info += "  Qt {0}{1}  PyQt {2}{3}".format(
         qVersion(), linesep, PYQT_VERSION_STR, linesep)
-    info += "  sip {0}{1}  QScintilla {2}{3}".format(
+    try:
+        from PyQt5 import QtChart
+        info += "  PyQtChart {0}".format(QtChart.PYQT_CHART_VERSION_STR)
+    except (ImportError, AttributeError):
+        pass
+    try:
+        from PyQt5 import QtWebEngine
+        info += "  PyQtWebEngine {0}".format(
+            QtWebEngine.PYQT_WEBENGINE_VERSION_STR)
+    except (ImportError, AttributeError):
+        pass
+    info += "  QScintilla {2}{3}  sip {0}{1}".format(
         sip_version_str, linesep, QSCINTILLA_VERSION_STR, linesep)
     try:
         from PyQt5 import QtWebEngineWidgets    # __IGNORE_WARNING__
