@@ -59,10 +59,21 @@ class CookiesExceptionsDialog(QDialog, Ui_CookiesExceptionsDialog):
             header = self.exceptionsTable.horizontalHeader().sectionSizeHint(
                 section)
             if section == 0:
-                header = fm.width("averagebiglonghost.averagedomain.info")
+                try:
+                    header = fm.horizontalAdvance(
+                        "averagebiglonghost.averagedomain.info")
+                except AttributeError:
+                    header = fm.width(
+                        "averagebiglonghost.averagedomain.info")
             elif section == 1:
-                header = fm.width(self.tr("Allow For Session"))
-            buffer = fm.width("mm")
+                try:
+                    header = fm.horizontalAdvance(self.tr("Allow For Session"))
+                except AttributeError:
+                    header = fm.width(self.tr("Allow For Session"))
+            try:
+                buffer = fm.horizontalAdvance("mm")
+            except AttributeError:
+                buffer = fm.width("mm")
             header += buffer
             self.exceptionsTable.horizontalHeader().resizeSection(
                 section, header)
