@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2016 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2016 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -90,7 +90,13 @@ class NetworkManager(QNetworkAccessManager):
                 QByteArray(b"qthelp"), self.__qtHelpSchemeHandler)
         
         self.__interceptor = NetworkUrlInterceptor(self)
-        WebBrowserWindow.webProfile().setRequestInterceptor(self.__interceptor)
+        try:
+            WebBrowserWindow.webProfile().setUrlRequestInterceptor(
+                self.__interceptor)
+        except AttributeError:
+            #  Qt < 5.13
+            WebBrowserWindow.webProfile().setRequestInterceptor(
+                self.__interceptor)
         
         WebBrowserWindow.cookieJar()
     
