@@ -67,12 +67,24 @@ class PasswordsDialog(QDialog, Ui_PasswordsDialog):
             header = self.passwordsTable.horizontalHeader().sectionSizeHint(
                 section)
             if section == 0:
-                header = fm.width("averagebiglongsitename")
+                try:
+                    header = fm.horizontalAdvance("averagebiglongsitename")
+                except AttributeError:
+                    header = fm.width("averagebiglongsitename")
             elif section == 1:
-                header = fm.width("averagelongusername")
+                try:
+                    header = fm.horizontalAdvance("averagelongusername")
+                except AttributeError:
+                    header = fm.width("averagelongusername")
             elif section == 2:
-                header = fm.width("averagelongpassword")
-            buffer = fm.width("mm")
+                try:
+                    header = fm.horizontalAdvance("averagelongpassword")
+                except AttributeError:
+                    header = fm.width("averagelongpassword")
+            try:
+                buffer = fm.horizontalAdvance("mm")
+            except AttributeError:
+                buffer = fm.width("mm")
             header += buffer
             self.passwordsTable.horizontalHeader().resizeSection(
                 section, header)
