@@ -11,6 +11,7 @@ This is the main Python script that performs the necessary initialization
 of the IDE and starts the Qt event loop.
 """
 
+# TODO: remove support for Qt4 and pyside (1)
 
 import sys
 import os
@@ -256,6 +257,9 @@ def main():
     
     sys.excepthook = excepthook
     
+    from PyQt5.QtGui import QGuiApplication
+    QGuiApplication.setDesktopFileName("eric6.desktop")
+    
     options = [
         ("--config=configDir",
          "use the given directory as the one containing the config files"),
@@ -303,7 +307,7 @@ def main():
         handleSingleApplication(ddindex)
     
     # set the search path for icons
-    Startup.initializeResourceSearchPath()
+    Startup.initializeResourceSearchPath(app)
     
     # generate and show a splash window, if not suppressed
     from UI.SplashScreen import SplashScreen, NoneSplashScreen
