@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -61,6 +61,9 @@ def main():
     """
     Main entry point into the application.
     """
+    from PyQt5.QtGui import QGuiApplication
+    QGuiApplication.setDesktopFileName("eric6_compare.desktop")
+    
     options = [
         ("--config=configDir",
          "use the given directory as the one containing the config files"),
