@@ -55,6 +55,9 @@ def main():
     """
     Main entry point into the application.
     """
+    from PyQt5.QtGui import QGuiApplication
+    QGuiApplication.setDesktopFileName("eric6_shell.desktop")
+    
     options = [
         ("--config=configDir",
          "use the given directory as the one containing the config files"),
