@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -67,6 +67,9 @@ def main():
     """
     global app
     
+    from PyQt5.QtGui import QGuiApplication
+    QGuiApplication.setDesktopFileName("eric6_trpreviewer.desktop")
+    
     options = [
         ("--config=configDir",
          "use the given directory as the one containing the config files"),
